California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 5, 2002, GENERAL
7 Measures
PROP 46 - HOUSING AND EMERGENCY SHELTER TRUST FUND ACT OF 2002.
PROP 47 - KINDERGARTEN-UNIVERSITY PUBLIC EDUCATION FACILITIES BOND ACT OF 2002.
PROP 48 - COURT CONSOLIDATION. LEGISLATIVE CONSTITUTIONAL AMENDMENT.
PROP 49 - BEFORE AND AFTER SCHOOL PROGRAMS. STATE GRANTS. INITIATIVE STATUTE.
PROP 50 - WATER QUALITY, SUPPLY AND SAFE DRINKING WATER PROJECTS. COASTAL WETLANDS PURCHASE AND PROTECTION. BONDS. INITIATIVE STATUTE.
PROP 51 - TRANSPORTATION. DISTRIBUTION OF EXISTING MOTOR VEHICLE SALES AND USE TAX. INITIATIVE STATUTE.
PROP 52 - ELECTION DAY VOTER REGISTRATION. VOTER FRAUD PENALITIES. INITATIVE STATUTE.
MARCH 5, 2002, PRIMARY
6 Measures
PROP 40 - CALIFORNIA CLEAN WATER, CLEAN AIR, SAFE NEIGHBORHOOD PARKS, AND COASTAL PROTECTION ACT OF 2002. AB. 1602 (2001)
PROP 41 - VOTING MODERNIZATION ACT OF 2002. AB 56 (2001)
PROP 42 - TRANSPORTATION FUNDING: SALES AND USE TAX REVENUES. ACA 4. (2001)
PROP 43 - RIGHT TO HAVE VOTE COUNTED. ACA 9. (2001).
PROP 44 - INSURANCE FRAUD. SB 1988. (2000).
PROP 45 - LEGISLATIVE TERM LIMITS. LOCAL VOTER PETITIONS. INITIATIVE CONSTITUTIONAL AMENDMENT.